// ---------------------------------------------------------------------------
// Created by F. Malpartida on 9/9/12.
// Copyright 2011 - Under creative commons license 3.0:
//        Attribution-NonCommercial-ShareAlike CC BY-NC-SA
//        http://www.electrofunltd.com
// 
// This software is furnished "as is", without technical support, and with no 
// warranty, express or implied, as to its usefulness for any purpose.
//
// Thread Safe: No
// Extendable: No
//
// @file mmi.cpp
// Main application MMI header files. 
// 
// @brief 
// Requires New LiquidCrystal library to be installed in system:
//    https://bitbucket.org/fmalpartida/new-liquidcrystal/wiki/Home
// Renders to an LCD module the main status of the CNC controller: axis position
// feed rates, on board temperature, fan speeds.
// MMI availability can be compiled out from the system by undifining the _MMI_ENABLED_
// flag from the configMe.h header file.
//
// @see mmi.h for class method documentation
//
//
// @author F. Malpartida
// ---------------------------------------------------------------------------
#include "mmi.h"

#ifdef _MMI_ENABLED_
#include <LCD.h>
#include "tempCntrl.h"
#include "stepperCntrl.h"

// CLASS CONSTRUCTORS
// ---------------------------------------------------------------------------
// Constructor
mmi::mmi ( void )
{
   _lcd       = NULL;
#ifdef _TEMP_CONTROL_ENABLED_
   _tempCont  = NULL;
#endif
   _machCntrl = NULL;
   _init      = false;
}

// PUBLIC CLASS METHODS
// ---------------------------------------------------------------------------
// Initialization methods
#ifdef _TEMP_CONTROL_ENABLED_
void mmi::init ( LCD *lcd, tempCntrl *temperatureController, stepperCntrl *controller )
{
   _lcd       = lcd;
   _tempCont  = temperatureController;
   _machCntrl = controller;
   _init      = true;
   
}
#else
void mmi::init ( LCD *lcd, stepperCntrl *controller )
{
   _lcd       = lcd;
   _machCntrl = controller;
   _init      = true;
   
}
#endif // _TEMP_CONTROL_ENABLED_

// LCD rendering
void mmi::display ( void )
{
   uint8_t speed;
   stepperCntrl::t_floatPoint pos;
   
#ifdef _TEMP_CONTROL_ENABLED_  
   speed = _tempCont->speedGet();
   
   // Read the current temperature form the sensor
   _lcd->setCursor ( 0,0 );
   _lcd->print ( "T:" );
   _lcd->print ( _tempCont->tempGet(), 1 );
   _lcd->print ("    S:");
   _lcd->print ( speed/100 );
   _lcd->print ( (speed % 100)/10 );
   _lcd->print ( (speed % 10) );
#endif
   
   pos = _machCntrl->getPosition ();
   _lcd->setCursor ( 0, 1 );
   _lcd->print (pos.x, 2);
   _lcd->print (" ");
   _lcd->print (pos.y, 2);
   _lcd->print (" ");
   _lcd->print (pos.z, 1);
   _lcd->print (" ");
   
#ifdef _DEBUG_
   Serial.print ( _tempCont->tempGet(), 1 );
   Serial.println ( speed  );
   
   Serial.print (pos.x, 1);
   Serial.print (" ");
   Serial.print (pos.y, 1);
   Serial.print (" ");
   Serial.println (pos.z, 1);
#endif
}
#endif // _MMI_ENABLED_